@@ -36,7 +36,6 @@
 
 #include <urcu/arch.h>
 #include <urcu/tls-compat.h>
-#include "cpuset.h"
 #include "thread-id.h"
 
 /* hardcoded number of CPUs */
@@ -93,7 +92,7 @@ pthread_mutex_t affinity_mutex = PTHREAD_MUTEX_INITIALIZER;
 
 static void set_affinity(void)
 {
-#if HAVE_SCHED_SETAFFINITY
+#ifdef HAVE_SCHED_SETAFFINITY
 	cpu_set_t mask;
 	int cpu, ret;
 #endif /* HAVE_SCHED_SETAFFINITY */
@@ -101,7 +100,7 @@ static void set_affinity(void)
 	if (!use_affinity)
 		return;
 
-#if HAVE_SCHED_SETAFFINITY
+#ifdef HAVE_SCHED_SETAFFINITY
 	ret = pthread_mutex_lock(&affinity_mutex);
 	if (ret) {
 		perror("Error in pthread mutex lock");
@@ -116,11 +115,7 @@ static void set_affinity(void)
 
 	CPU_ZERO(&mask);
 	CPU_SET(cpu, &mask);
-#if SCHED_SETAFFINITY_ARGS == 2
-	sched_setaffinity(0, &mask);
-#else
 	sched_setaffinity(0, sizeof(mask), &mask);
-#endif
 #endif /* HAVE_SCHED_SETAFFINITY */
 }
 
@@ -306,23 +301,23 @@ static void *thr_dequeuer(void *_count)
 	return ((void*)2);
 }
 
-static void test_end(struct cds_lfs_stack *s, unsigned long long *nr_dequeues)
+static void test_end(unsigned long long *nr_dequeues_l)
 {
 	struct cds_lfs_node *snode;
 
 	do {
-		snode = __cds_lfs_pop(s);
+		snode = __cds_lfs_pop(&s);
 		if (snode) {
 			struct test *node;
 
 			node = caa_container_of(snode, struct test, list);
 			free(node);
-			(*nr_dequeues)++;
+			(*nr_dequeues_l)++;
 		}
 	} while (snode);
 }
 
-static void show_usage(int argc, char **argv)
+static void show_usage(char **argv)
 {
 	printf("Usage : %s nr_dequeuers nr_enqueuers duration (s) <OPTIONS>\n",
 		argv[0]);
@@ -349,27 +344,28 @@ int main(int argc, char **argv)
 			   tot_successful_dequeues = 0;
 	unsigned long long end_dequeues = 0;
 	int i, a;
+	unsigned int i_thr;
 
 	if (argc < 4) {
-		show_usage(argc, argv);
+		show_usage(argv);
 		return -1;
 	}
 
 	err = sscanf(argv[1], "%u", &nr_dequeuers);
 	if (err != 1) {
-		show_usage(argc, argv);
+		show_usage(argv);
 		return -1;
 	}
 
 	err = sscanf(argv[2], "%u", &nr_enqueuers);
 	if (err != 1) {
-		show_usage(argc, argv);
+		show_usage(argv);
 		return -1;
 	}
-	
+
 	err = sscanf(argv[3], "%lu", &duration);
 	if (err != 1) {
-		show_usage(argc, argv);
+		show_usage(argv);
 		return -1;
 	}
 
@@ -379,7 +375,7 @@ int main(int argc, char **argv)
 		switch (argv[i][1]) {
 		case 'a':
 			if (argc < i + 2) {
-				show_usage(argc, argv);
+				show_usage(argv);
 				return -1;
 			}
 			a = atoi(argv[++i]);
@@ -389,14 +385,14 @@ int main(int argc, char **argv)
 			break;
 		case 'c':
 			if (argc < i + 2) {
-				show_usage(argc, argv);
+				show_usage(argv);
 				return -1;
 			}
 			rduration = atol(argv[++i]);
 			break;
 		case 'd':
 			if (argc < i + 2) {
-				show_usage(argc, argv);
+				show_usage(argv);
 				return -1;
 			}
 			wdelay = atol(argv[++i]);
@@ -448,15 +444,15 @@ int main(int argc, char **argv)
 
 	next_aff = 0;
 
-	for (i = 0; i < nr_enqueuers; i++) {
-		err = pthread_create(&tid_enqueuer[i], NULL, thr_enqueuer,
-				     &count_enqueuer[2 * i]);
+	for (i_thr = 0; i_thr < nr_enqueuers; i_thr++) {
+		err = pthread_create(&tid_enqueuer[i_thr], NULL, thr_enqueuer,
+				     &count_enqueuer[2 * i_thr]);
 		if (err != 0)
 			exit(1);
 	}
-	for (i = 0; i < nr_dequeuers; i++) {
-		err = pthread_create(&tid_dequeuer[i], NULL, thr_dequeuer,
-				     &count_dequeuer[2 * i]);
+	for (i_thr = 0; i_thr < nr_dequeuers; i_thr++) {
+		err = pthread_create(&tid_dequeuer[i_thr], NULL, thr_dequeuer,
+				     &count_dequeuer[2 * i_thr]);
 		if (err != 0)
 			exit(1);
 	}
@@ -465,7 +461,7 @@ int main(int argc, char **argv)
 
 	test_go = 1;
 
-	for (i = 0; i < duration; i++) {
+	for (i_thr = 0; i_thr < duration; i_thr++) {
 		sleep(1);
 		if (verbose_mode) {
 			fwrite(".", sizeof(char), 1, stdout);
@@ -475,22 +471,22 @@ int main(int argc, char **argv)
 
 	test_stop = 1;
 
-	for (i = 0; i < nr_enqueuers; i++) {
-		err = pthread_join(tid_enqueuer[i], &tret);
+	for (i_thr = 0; i_thr < nr_enqueuers; i_thr++) {
+		err = pthread_join(tid_enqueuer[i_thr], &tret);
 		if (err != 0)
 			exit(1);
-		tot_enqueues += count_enqueuer[2 * i];
-		tot_successful_enqueues += count_enqueuer[2 * i + 1];
+		tot_enqueues += count_enqueuer[2 * i_thr];
+		tot_successful_enqueues += count_enqueuer[2 * i_thr + 1];
 	}
-	for (i = 0; i < nr_dequeuers; i++) {
-		err = pthread_join(tid_dequeuer[i], &tret);
+	for (i_thr = 0; i_thr < nr_dequeuers; i_thr++) {
+		err = pthread_join(tid_dequeuer[i_thr], &tret);
 		if (err != 0)
 			exit(1);
-		tot_dequeues += count_dequeuer[2 * i];
-		tot_successful_dequeues += count_dequeuer[2 * i + 1];
+		tot_dequeues += count_dequeuer[2 * i_thr];
+		tot_successful_dequeues += count_dequeuer[2 * i_thr + 1];
 	}
-	
-	test_end(&s, &end_dequeues);
+
+	test_end(&end_dequeues);
 
 	printf_verbose("total number of enqueues : %llu, dequeues %llu\n",
 		       tot_enqueues, tot_dequeues);
@@ -519,5 +515,6 @@ int main(int argc, char **argv)
 	free(count_dequeuer);
 	free(tid_enqueuer);
 	free(tid_dequeuer);
+
 	return 0;
 }
