@@ -33,7 +33,6 @@
 
 #include <urcu/arch.h>
 #include <urcu/tls-compat.h>
-#include "cpuset.h"
 #include "thread-id.h"
 #include "../common/debug-yield.h"
 
@@ -81,7 +80,7 @@ pthread_mutex_t affinity_mutex = PTHREAD_MUTEX_INITIALIZER;
 
 static void set_affinity(void)
 {
-#if HAVE_SCHED_SETAFFINITY
+#ifdef HAVE_SCHED_SETAFFINITY
 	cpu_set_t mask;
 	int cpu, ret;
 #endif /* HAVE_SCHED_SETAFFINITY */
@@ -89,7 +88,7 @@ static void set_affinity(void)
 	if (!use_affinity)
 		return;
 
-#if HAVE_SCHED_SETAFFINITY
+#ifdef HAVE_SCHED_SETAFFINITY
 	ret = pthread_mutex_lock(&affinity_mutex);
 	if (ret) {
 		perror("Error in pthread mutex lock");
@@ -103,11 +102,7 @@ static void set_affinity(void)
 	}
 	CPU_ZERO(&mask);
 	CPU_SET(cpu, &mask);
-#if SCHED_SETAFFINITY_ARGS == 2
-	sched_setaffinity(0, &mask);
-#else
 	sched_setaffinity(0, sizeof(mask), &mask);
-#endif
 #endif /* HAVE_SCHED_SETAFFINITY */
 }
 
@@ -132,27 +127,7 @@ static unsigned int nr_writers;
 
 pthread_mutex_t rcu_copy_mutex = PTHREAD_MUTEX_INITIALIZER;
 
-void rcu_copy_mutex_lock(void)
-{
-	int ret;
-	ret = pthread_mutex_lock(&rcu_copy_mutex);
-	if (ret) {
-		perror("Error in pthread mutex lock");
-		exit(-1);
-	}
-}
-
-void rcu_copy_mutex_unlock(void)
-{
-	int ret;
-
-	ret = pthread_mutex_unlock(&rcu_copy_mutex);
-	if (ret) {
-		perror("Error in pthread mutex unlock");
-		exit(-1);
-	}
-}
-
+static
 void *thr_reader(void *_count)
 {
 	unsigned long long *count = _count;
@@ -206,6 +181,7 @@ void *thr_reader(void *_count)
 
 }
 
+static
 void *thr_writer(void *_count)
 {
 	unsigned long long *count = _count;
@@ -245,7 +221,8 @@ void *thr_writer(void *_count)
 	return ((void*)2);
 }
 
-void show_usage(int argc, char **argv)
+static
+void show_usage(char **argv)
 {
 	printf("Usage : %s nr_readers nr_writers duration (s) <OPTIONS>\n",
 		argv[0]);
@@ -267,27 +244,28 @@ int main(int argc, char **argv)
 	unsigned long long *count_reader, *count_writer;
 	unsigned long long tot_reads = 0, tot_writes = 0;
 	int i, a;
+	unsigned int i_thr;
 
 	if (argc < 4) {
-		show_usage(argc, argv);
+		show_usage(argv);
 		return -1;
 	}
 
 	err = sscanf(argv[1], "%u", &nr_readers);
 	if (err != 1) {
-		show_usage(argc, argv);
+		show_usage(argv);
 		return -1;
 	}
 
 	err = sscanf(argv[2], "%u", &nr_writers);
 	if (err != 1) {
-		show_usage(argc, argv);
+		show_usage(argv);
 		return -1;
 	}
-	
+
 	err = sscanf(argv[3], "%lu", &duration);
 	if (err != 1) {
-		show_usage(argc, argv);
+		show_usage(argv);
 		return -1;
 	}
 
@@ -303,7 +281,7 @@ int main(int argc, char **argv)
 			break;
 		case 'a':
 			if (argc < i + 2) {
-				show_usage(argc, argv);
+				show_usage(argv);
 				return -1;
 			}
 			a = atoi(argv[++i]);
@@ -313,21 +291,21 @@ int main(int argc, char **argv)
 			break;
 		case 'c':
 			if (argc < i + 2) {
-				show_usage(argc, argv);
+				show_usage(argv);
 				return -1;
 			}
 			rduration = atol(argv[++i]);
 			break;
 		case 'd':
 			if (argc < i + 2) {
-				show_usage(argc, argv);
+				show_usage(argv);
 				return -1;
 			}
 			wdelay = atol(argv[++i]);
 			break;
 		case 'e':
 			if (argc < i + 2) {
-				show_usage(argc, argv);
+				show_usage(argv);
 				return -1;
 			}
 			wduration = atol(argv[++i]);
@@ -352,15 +330,15 @@ int main(int argc, char **argv)
 
 	next_aff = 0;
 
-	for (i = 0; i < nr_readers; i++) {
-		err = pthread_create(&tid_reader[i], NULL, thr_reader,
-				     &count_reader[i]);
+	for (i_thr = 0; i_thr < nr_readers; i_thr++) {
+		err = pthread_create(&tid_reader[i_thr], NULL, thr_reader,
+				     &count_reader[i_thr]);
 		if (err != 0)
 			exit(1);
 	}
-	for (i = 0; i < nr_writers; i++) {
-		err = pthread_create(&tid_writer[i], NULL, thr_writer,
-				     &count_writer[i]);
+	for (i_thr = 0; i_thr < nr_writers; i_thr++) {
+		err = pthread_create(&tid_writer[i_thr], NULL, thr_writer,
+				     &count_writer[i_thr]);
 		if (err != 0)
 			exit(1);
 	}
@@ -373,19 +351,19 @@ int main(int argc, char **argv)
 
 	test_stop = 1;
 
-	for (i = 0; i < nr_readers; i++) {
-		err = pthread_join(tid_reader[i], &tret);
+	for (i_thr = 0; i_thr < nr_readers; i_thr++) {
+		err = pthread_join(tid_reader[i_thr], &tret);
 		if (err != 0)
 			exit(1);
-		tot_reads += count_reader[i];
+		tot_reads += count_reader[i_thr];
 	}
-	for (i = 0; i < nr_writers; i++) {
-		err = pthread_join(tid_writer[i], &tret);
+	for (i_thr = 0; i_thr < nr_writers; i_thr++) {
+		err = pthread_join(tid_writer[i_thr], &tret);
 		if (err != 0)
 			exit(1);
-		tot_writes += count_writer[i];
+		tot_writes += count_writer[i_thr];
 	}
-	
+
 	printf_verbose("total number of reads : %llu, writes %llu\n", tot_reads,
 	       tot_writes);
 	printf("SUMMARY %-25s testdur %4lu nr_readers %3u rdur %6lu wdur %6lu "
